Read neuron skeletons via neuprint
Usage
read_fish_neurons(
ids,
connectors = FALSE,
units = c("nm", "raw", "microns"),
heal.threshold = Inf,
conn = NULL,
...,
dataset = fish_default_dataset()
)Arguments
- ids
Body ids in any form compatible with
fish_ids.- connectors
Whether to fetch synaptic connections for the neuron (default
FALSEin contrast toneuprint_read_neurons).- units
Units of the returned neurons (default
"nm").- heal.threshold
The threshold for healing disconnected skeleton fragments. The default of
Infensures that all fragments are joined together.- conn
Optional, a
neuprint_connectionobject. Defaults tofish_neuprintto ensure that the query targets fish2.- ...
Additional arguments passed to
neuprint_read_neurons.- dataset
The name of the dataset as reported in Clio (default
"fish2").
Value
A neuronlist object containing one or
more neurons.
See also
manc_read_neurons, and nat functions
including neuron, neuronlist.
Other 3d-meshes-skeletons:
fish_roi_meshes(),
fish_rois(),
read_fish_meshes()
Examples
# \donttest{
rgcsk3 <- read_fish_neurons(fish_ids("RGC")[1:3])
#> Warning: Clio dataset lookup failed; falling back to baked-in neuprint settings for `fish2`. Clio-backed functionality may be unavailable in this session.
#> Warning: Clio dataset lookup failed; falling back to baked-in neuprint settings for `fish2`. Clio-backed functionality may be unavailable in this session.
plot(rgcsk3, WithNodes=FALSE)
# }