Set one or more Clio body annotations for the fish2 dataset.
Usage
fish_annotate(
x,
test = TRUE,
version = NULL,
write_empty_fields = FALSE,
allow_new_fields = FALSE,
designated_user = NULL,
protect = c("user"),
chunksize = 50,
...
)Arguments
- x
Annotation data usually as a data.frame containing a bodyid column. Please see
malevnc::manc_annotate_bodyfor other options.- test
Whether to use the clio test sore
- version
Optional clio version to associate with this annotation. The default
NULLuses the current version returned by the API.- write_empty_fields
When
xis a data.frame, this controls whether empty fields inx(i.e.NAor"") overwrite fields in the clio-store database (when they are not protected by theprotectargument). The (conservative) defaultwrite_empty_fields=FALSEdoes not overwrite. If you do want to set fields to an empty value (usually the empty string) then you must setwrite_empty_fields=TRUE.- allow_new_fields
Whether to allow creation of new clio fields. Default
FALSEwill produce an error encouraging you to check the field names.- designated_user
Optional email address when one person is uploading annotations on behalf of another user. See Users section for details.
- protect
Vector of fields that will not be overwritten if they already have a value in clio store. Set to
TRUEto protect all fields and toFALSEto overwrite all fields for which you provide data. See details for the rationale behind the default value of "user"- chunksize
When you have many bodies to annotate the request will by default be sent 50 records at a time to avoid any issue with timeouts. Set to
Infto insist that all records are sent in a single request. NB only applies whenxis a data.frame.- ...
Additional parameters passed to
pbapply::pbsapply
Value
The result returned by manc_annotate_body.
Details
This function sets annotations for one or more bodyids. Logically these annotations move with the bodyid (rather than a point location on the object). The rules for annotation merges/transfers seem to work well in practice but in general detailed annotations should be reserved for large/mature bodies.
The function wraps malevnc::manc_annotate_body for
the fish2 dataset. The default test=TRUE is retained for safety, but
there does not currently appear to be a separate fish2 annotation test
server. Please inspect the returned metadata carefully before assuming the
result matches what you intended to write.
See also
Other live-annotations:
fish_dvid_annotations()
Examples
if (FALSE) { # \dontrun{
fish_annotate(data.frame(bodyid = 100003384, group = 100003384), test = TRUE)
} # }