Login to fish2 neuprint server
Usage
fish_neuprint(
token = fish_neuprint_token(),
dataset = NULL,
Force = FALSE,
use_clio = FALSE,
...
)Arguments
- token
neuprint authorisation token obtained e.g. from neuprint.janelia.org website.
- dataset
Allows you to override the neuprint dataset for
fish_neuprint(which would otherwise be chosen based on the value ofoptions(fishr.dataset), normally changed bychoose_fish_dataset).- Force
Passed to
neuprintr::neuprint_login.- use_clio
Whether to use a live Clio lookup for fish dataset settings before opening the neuprint connection. The default
FALSEreuses cached live lookup results when available and otherwise relies on built-in fish2 neuprint settings.- ...
Additional arguments passed to
neuprint_login.
Value
A neuprint_connection object returned by
neuprint_login.
Details
It should be possible to use the same token across public and
private neuprint servers if you are using the same email address. However
this does not seem to work for all users. Before giving up on this, do try
using the most recently issued token from a private server rather
than older tokens. If you need to pass a specific token you can use the
token argument, also setting Force=TRUE to ensure that the
specified token is used if you have already tried to log in during the
current session.
See also
Other setup-data-access:
fish_setup(),
fishr-package,
with_fish()