Skip to contents

Fetch neuprint metadata for fish2 neurons

Usage

fish_neuprint_meta(
  ids = NULL,
  conn = NULL,
  roiInfo = FALSE,
  simplify.xyz = TRUE,
  ...,
  dataset = fish_default_dataset()
)

Arguments

ids

Body ids, a query string (see fish_ids), or NULL to return all bodies known to neuprint.

conn

Optional, a neuprint_connection object. Defaults to fish_neuprint to ensure that the query targets fish2.

roiInfo

Whether to include ROI information (default FALSE).

simplify.xyz

Whether to simplify columns containing XYZ locations to a simple "x,y,z" format (default TRUE).

...

Additional arguments passed to neuprint_get_meta.

dataset

The name of the dataset as reported in Clio (default "fish2").

Value

A data.frame with one row for each unique input id and NAs for all columns except bodyid when neuprint holds no metadata.

Examples

# \donttest{
head(fish_neuprint_meta("RGC"))
#> Warning: Clio dataset lookup failed; falling back to baked-in neuprint settings for `fish2`. Clio-backed functionality may be unavailable in this session.
#>      bodyid post pre downstream upstream synweight nsoma somaSide
#> 1 110656660    8 219        229        8       237     0     <NA>
#> 2 100009896    2  89         90        2        92     0     <NA>
#> 3 100015071    0 128        135        0       135     0     <NA>
#> 4 100015468    2 290        316        2       318     0     <NA>
#> 5 100017513    7 245        252        7       259     0     <NA>
#> 6 100023948    1 167        173        1       174     0     <NA>
#>      statusLabel connectivityType  name type group perNodeSc proposedType
#> 1 Sensory Anchor             <NA> RGC_R  RGC     0        NA         <NA>
#> 2 Sensory Anchor             <NA> RGC_R  RGC     0        NA         <NA>
#> 3 Sensory Anchor             <NA> RGC_R  RGC     0        NA         <NA>
#> 4 Sensory Anchor             <NA> RGC_R  RGC     0        NA         <NA>
#> 5 Sensory Anchor             <NA> RGC_R  RGC     0        NA         <NA>
#> 6 Sensory Anchor             <NA> RGC_R  RGC     0        NA         <NA>
#>   keywords class comment somaLocation somaId somaVoxels zapbenchId
#> 1     <NA>  <NA>    <NA>         <NA>     NA         NA         NA
#> 2     <NA>  <NA>    <NA>         <NA>     NA         NA         NA
#> 3     <NA>  <NA>    <NA>         <NA>     NA         NA         NA
#> 4     <NA>  <NA>    <NA>         <NA>     NA         NA         NA
#> 5     <NA>  <NA>    <NA>         <NA>     NA         NA         NA
#> 6     <NA>  <NA>    <NA>         <NA>     NA         NA         NA
#>   closestLandmarkDistanceMicrons tosomaLocation status   voxels  soma
#> 1                             NA           <NA> Anchor  9735937 FALSE
#> 2                             NA           <NA> Anchor  6228154 FALSE
#> 3                             NA           <NA> Anchor  5774341 FALSE
#> 4                             NA           <NA> Anchor  9488378 FALSE
#> 5                             NA           <NA> Anchor 10752622 FALSE
#> 6                             NA           <NA> Anchor  6913578 FALSE
# }