Fetch the ROI hierarchy for fish2
Usage
fish_rois(
root = NULL,
rval = c("edgelist", "graph"),
cache = FALSE,
conn = NULL,
...,
dataset = fish_default_dataset()
)Arguments
- root
Character vector specifying a root ROI. The default (
NULL) returns the whole hierarchy.- rval
Whether to return an edge list
data.frame(default) or anigraphobject.- cache
if
TRUEwill use memoisation to cache the result of the call for 24 hours.- conn
Optional, a
neuprint_connectionobject. Defaults tofish_neuprintto ensure that the query targets fish2.- ...
Additional arguments passed to
neuprint_ROI_hierarchy.- dataset
optional, a dataset you want to query. If
NULL, the default specified by your R environ file is used or, failing that the current connection, is used. Seeneuprint_loginfor details.
See also
neuprint_ROI_hierarchy,
fish_roi_meshes
Other 3d-meshes-skeletons:
fish_roi_meshes(),
read_fish_meshes(),
read_fish_neurons()
Examples
# \donttest{
head(fish_rois())
#> parent roi
#> 1 fish2 Brain
#> 2 Brain Mece
#> 3 Mece Retina
#> 4 Mece Forebrain
#> 5 Forebrain Olfactory_Bulb
#> 6 Forebrain Telencephalon
# }