A thin wrapper around the malevnc package providing access to the fish2 larval zebrafish EM dataset being proofread at Janelia Research Campus as part of a collaboration with the Engert / Lichtman labs at Harvard and Google Research. Currently provides convenience functions for reading meshes and setting dataset options.
Package Options
fishr.datasetThe name of the active fish2 dataset (default"fish2"). Set bychoose_fish_dataset.
The following malevnc.* options are set by choose_fish
or with_fish to point the malevnc package at the fish2
servers:
malevnc.serverDVID server URL (set via Clio lookup).malevnc.rootnodeDVID root node UUID (set via Clio lookup).malevnc.neuprintneuprint server URL (fallback:https://neuprint-fish2.janelia.org).malevnc.neuprint_datasetneuprint dataset name (fallback:"fish2").
See also
Useful links:
Other setup-data-access:
fish_neuprint(),
fish_setup(),
with_fish()
Author
Maintainer: Gregory Jefferis jefferis@gmail.com (ORCID)